@@ -48,7 +48,7 @@ if DATADOG_INSTALLED:
                 metric_name = metric.format_name(
                     metric_prefix_name=self.metric_prefix_name
                 )
-                logger.debug(
+                logger.info(
                     f"Sending metric[{metric_name}] with value [{metric_value}] and tags{metric.format_tags()} to Datadog."
                 )
                 self.stats.gauge(metric_name, metric_value, tags=metric.format_tags())
